#!/usr/bin/perl -w

=head1 NAME

db_upgrade.pl - installation script to run db upgrade scripts

=head1 VERSION

$Revision: 1.7 $

=head1 DATE

$Date: 2004/02/06 06:34:53 $

=head1 DESCRIPTION

This script is called by "make upgrade" to run the database upgrade
scripts.  Uses upgrade.db to determine which ones to run.

When multiple scripts are run, they are run in sorted ASCII-betical
order (via perl's C<sort()> function).

=head1 AUTHOR

Sam Tregar <stregar@about-inc.com>

=head1 SEE ALSO

L<Bric::Admin>

=cut

use strict;
use FindBin;
use lib "$FindBin::Bin/lib";
use Bric::Inst qw(:all);
use File::Spec::Functions qw(:ALL);
use Data::Dumper;

our $UPGRADE;
do "./upgrade.db" or die "Failed to read upgrade.db : $!";
our $CONFIG;
do "./config.db" or die "Failed to read config.db : $!";
our $PG;
do './postgres.db' or die "Failed to read postgres.db : $!";

print "\n\n==> Starting Database Upgrade <==\n\n";

# setup environment to ensure scripts run correctly
$ENV{BRICOLAGE_ROOT} = $UPGRADE->{BRICOLAGE_ROOT};
my $perl = $ENV{PERL} || $^X;

# run the upgrade scripts
foreach my $v (@{$UPGRADE->{TODO}}) {
    my $dir = catdir("inst", "upgrade", $v);
    print "Looking for scripts for $v in $dir\n";
    next unless -d $dir;

    opendir(DIR, $dir) or die "can't opendir $dir: $!";
    my @scripts = grep { -f $_ } map { catfile($dir, $_) } sort readdir(DIR);
    closedir DIR;

    foreach my $script (@scripts) {
	print "Running '$perl $script'.\n";
	my $ret = system("$perl", "-I$CONFIG->{MODULE_DIR}", $script, '-u',
                         $PG->{root_user}, '-p', $PG->{root_pass});
        # Pass through abnormal exits so that `make` will be halted.
        exit $ret / 256 if $ret;
    }
}

print "\n\n==> Finished Database Upgrade <==\n\n";
